@@ -301,8 +301,14 @@ class BGLDataset(LogDataset):
                 anomalous_event_ids_dict[f'{event_id}_a'] = 1
                 anomalous_event_ids_dict[f'{event_id}_n'] = 1
 
-                self.templates = pd.concat([self.templates, pd.DataFrame({"EventId": f'{event_id}_a'}),
-                                            pd.DataFrame({"EventId": f'{event_id}_n'})])
+                self.templates = pd.concat(
+                    [self.templates,
+                     pd.DataFrame([
+                         {"EventId": f'{event_id}_a'},
+                         {"EventId": f'{event_id}_n'}
+                     ])
+                     ]
+                )
 
             else:  #
                 del anomalous_event_ids_dict[event_id]
